@@ -1,20 +1,9 @@
-# Euler. R
-
-# /**
-# * Euler implements an Euler method ODE solver.
-# *
-# * The Euler method is unstable for many systems.  It is included as an
-# * example of how to use the ODE and ODESolver interface.
-# *
-# * @author              Wolfgang Christian
-# * @version 1.0
-# * converted to R by    Alfonso R> Reyes
-# */
 
 
-#' Euler class
-#'
+#' Euler ODE solver class
 #' @param ode an ODE object
+#' @param object an internal object of the class
+#' @param stepSize the size of the step
 #' @param ... additional parameters
 #'
 #' @rdname Euler-class
@@ -23,6 +12,16 @@
             contains = c("AbstractODESolver")
         )
 
+#' Euler generic
+#'
+#' @rdname Euler-class
+#' @export
+#' @example ./inst/examples/RigidBodyNXFApp.R
+setGeneric("Euler", function(ode, ...)   standardGeneric("Euler"))
+
+# #' @param .Object internal object for initialize
+# #' @rdname Euler-class
+# #' @aliases initialize,initialize-method
 setMethod("initialize", "Euler", function(.Object, ode, ...) {
     tryCatch({
         if (missing(ode)) stop("ode param not supplied")
@@ -35,7 +34,8 @@ setMethod("initialize", "Euler", function(.Object, ode, ...) {
 })
 
 
-#' @rdname init-method
+#' @rdname Euler-class
+#' @aliases init,init-method
 #' @importFrom methods callNextMethod
 setMethod("init", "Euler", function(object, stepSize, ...) {
     object <- callNextMethod(object, stepSize)           # call superclass init
@@ -44,7 +44,8 @@ setMethod("init", "Euler", function(object, stepSize, ...) {
 })
 
 
-#' @rdname step-method
+#' @rdname Euler-class
+#' @aliases step,step-method
 setMethod("step", signature(object = "Euler"), function(object, ...) {
     # step through the differential equation
     state <- getState(object@ode)                         # get the state
@@ -59,20 +60,25 @@ setMethod("step", signature(object = "Euler"), function(object, ...) {
 
 })
 
-
-#' @rdname setStepSize-method
+#' @rdname Euler-class
+#' @aliases setStepSize,setStepSize-method
 setMethod("setStepSize", "Euler", function(object, stepSize, ...) {
     # set the time step
     object@stepSize <-  stepSize
     invisible(object)
 })
 
-#' @rdname setStepSize-method
+#' @rdname Euler-class
+#' @aliases getStepSize,getStepSize-method
 setMethod("getStepSize", "Euler", function(object, ...) {
     return(object@stepSize)
 })
 
 
+
+
+
+
 #' Euler constructor when `ODE` passed
 #'
 #' @rdname Euler-class
@@ -104,3 +110,21 @@ setMethod("Euler", signature(ode = "missing"), function(ode, ...) {
     .euler <- init(.euler, .euler@stepSize)
     return(.euler)
 })
+
+
+
+
+
+
+# Euler. R
+
+# /**
+# * Euler implements an Euler method ODE solver.
+# *
+# * The Euler method is unstable for many systems.  It is included as an
+# * example of how to use the ODE and ODESolver interface.
+# *
+# * @author              Wolfgang Christian
+# * @version 1.0
+# * converted to R by    Alfonso R> Reyes
+# */
